@@ -81,7 +81,8 @@ if (isset($_POST["rubdoc"])) {
             'width'     => '50%',
             'entity'    => intval($_POST['entity']),
             'rand'      => intval($_POST['rand']),
-            'condition' => ['glpi_documents.documentcategories_id' => (int)$_POST["rubdoc"]]
+            'condition' => ['glpi_documents.documentcategories_id' => (int)$_POST["rubdoc"]],
+            'value'     => (int)($_POST['value'] ?? -1),
         ]
     );
 }
