@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -43,13 +43,20 @@ if (
     isset($_REQUEST["urgency"])
     && isset($_REQUEST["impact"])
 ) {
-    $priority = Ticket::computePriority($_REQUEST["urgency"], $_REQUEST["impact"]);
+    // Read predefined templates fields
+    $predefined_fields  = array_key_exists('_predefined_fields', $_REQUEST) ? Toolbox::decodeArrayFromInput($_REQUEST["_predefined_fields"]) : [];
+
+    // Fallback to Form value -> Template values -> Medium
+    $priority = Ticket::computePriority(
+        $_REQUEST["urgency"] ?: $predefined_fields['urgency'] ?? 3 /* Medium */,
+        $_REQUEST["impact"]  ?: $predefined_fields['impact']  ?? 3 /* Medium */
+    );
 
     if (isset($_REQUEST['getJson'])) {
         header("Content-Type: application/json; charset=UTF-8");
         echo json_encode(['priority' => $priority]);
-    } else if ($_REQUEST["priority"]) {
-       // Send UTF8 Headers
+    } elseif ($_REQUEST["priority"]) {
+        // Send UTF8 Headers
         header("Content-Type: text/html; charset=UTF-8");
         echo "<script type='text/javascript' >\n";
         echo Html::jsSetDropdownValue($_REQUEST["priority"], $priority);
