@@ -47,7 +47,7 @@ if (isset($_GET["embed"]) && isset($_GET["dashboard"])) {
     $grid      = new Glpi\Dashboard\Grid($_GET["dashboard"]);
     $dashboard = $grid->getDashboard();
     Html::zeroSecurityIframedHeader($grid->getDashboard()->getTitle(), 'central', 'central');
-    echo $grid->embed($_REQUEST);
+    $grid->embed($_REQUEST);
     Html::popFooter();
     exit;
 }
