@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -48,6 +48,10 @@ if ($conf->enabled_inventory != 1) {
 }
 
 $inventory_request = new Request();
+if ($inventory_request->inError() && $inventory_request->getHttpResponseCode() == 415) {
+    http_response_code($inventory_request->getHttpResponseCode());
+    die("Unsupported compression");
+}
 $inventory_request->handleHeaders();
 
 $refused = new RefusedEquipment();
