@@ -50,16 +50,17 @@ Html::header(__('Statistics'), $_SERVER['PHP_SELF'], "helpdesk", "stat");
 
 Session::checkRight("statistic", READ);
 
+/** @var CommonITILObject $item */
 if (!$item = getItemForItemtype($_GET['itemtype'])) {
     exit;
 }
 
 //sanitize dates
 foreach (['date1', 'date2'] as $key) {
-    if (array_key_exists($key, $_GET) && preg_match('/\d{4}-\d{2}-\d{2}/', (string)$_GET[$key]) !== 1) {
+    if (array_key_exists($key, $_GET) && preg_match('/^\d{4}-\d{2}-\d{2}$/', (string)$_GET[$key]) !== 1) {
         unset($_GET[$key]);
     }
-    if (array_key_exists($key, $_POST) && preg_match('/\d{4}-\d{2}-\d{2}/', (string)$_POST[$key]) !== 1) {
+    if (array_key_exists($key, $_POST) && preg_match('/^\d{4}-\d{2}-\d{2}$/', (string)$_POST[$key]) !== 1) {
         unset($_POST[$key]);
     }
 }
