@@ -37,10 +37,16 @@
  * @var \Migration $migration
  */
 
-$migration->displayMessage('Add new configurations / user preferences');
-$migration->addConfig([
-    'timeline_action_btn_layout'   => 0,
-    'timeline_date_format'   => 0,
-]);
-$migration->addField('glpi_users', 'timeline_action_btn_layout', 'tinyint DEFAULT 0');
-$migration->addField('glpi_users', 'timeline_date_format', 'tinyint DEFAULT 0');
+$migration->changeField(
+    'glpi_users',
+    'timeline_action_btn_layout',
+    'timeline_action_btn_layout',
+    'tinyint DEFAULT NULL'
+);
+
+$migration->changeField(
+    'glpi_users',
+    'timeline_date_format',
+    'timeline_date_format',
+    'tinyint DEFAULT NULL'
+);
