@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -35,15 +35,17 @@
 
 /**
  * @var \DBmysql $DB
+ * @var \Migration $migration
  */
 
-$DB->updateOrDie(
-    'glpi_rulecriterias',
-    [
-        'criteria' => '_locations_id_of_item'
-    ],
-    [
-        'criteria' => 'items_locations'
-    ],
-    '10.0.8 replace old rule criteria items_locations'
+$migration->addPostQuery(
+    $DB->buildUpdate(
+        'glpi_rulecriterias',
+        [
+            'criteria' => 'users_id_recipient',
+        ],
+        [
+            'criteria' => '_users_id_recipient',
+        ]
+    )
 );
