@@ -5,7 +5,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -630,7 +630,17 @@ var urlExists = function(url) {
  * @return {string}  The formated size
  */
 var getSize = function (size) {
-    var bytes   = ['o', 'Kio', 'Mio', 'Gio', 'Tio'];
+    var bytes = [
+        _x('size', 'B'),
+        _x('size', 'KiB'),
+        _x('size', 'MiB'),
+        _x('size', 'GiB'),
+        _x('size', 'TiB'),
+        _x('size', 'PiB'),
+        _x('size', 'EiB'),
+        _x('size', 'ZiB'),
+        _x('size', 'YiB'),
+    ];
     var lastval = '';
     bytes.some(function(val) {
         if (size > 1024) {
