@@ -5,7 +5,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -48,6 +48,16 @@ window.$.migrateTrace = false;
 // jQuery plugins
 require('fittext.js');
 
+// jQuery UI widgets required by
+// - jquery-file-upload (widget)
+// - jquery.fancytree (widget, position, jquery-patch, keycode, scroll-parent, unique-id)
+require('jquery-ui/ui/widget');
+require('jquery-ui/ui/position');
+require('jquery-ui/ui/jquery-patch');
+require('jquery-ui/ui/keycode');
+require('jquery-ui/ui/scroll-parent');
+require('jquery-ui/ui/unique-id');
+
 // jQuery fancttree
 require('jquery.fancytree');
 require('jquery.fancytree/dist/modules/jquery.fancytree.grid');
@@ -59,11 +69,6 @@ import PlainScrollbar from 'exports-loader?exports=default|PlainScrollbar!plain-
 import 'plain-scrollbar/plain-scrollbar.css';
 window.PlainScrollbar = PlainScrollbar;
 
-
-// jQuery UI widgets required by
-// - jquery-file-upload (widget)
-require('jquery-ui/ui/widget');
-
 // Tabler
 import '@tabler/core';
 
