@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -44,4 +44,9 @@ class AllAssets extends CommonGLPI
     {
         return _n('Asset', 'Assets', $nb);
     }
+
+    public static function getIcon()
+    {
+        return 'ti ti-packages';
+    }
 }
