@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -244,7 +244,7 @@ class Appliance_Item_Relation extends CommonDBRelation
      * @return string the javascript
      */
     public static function getListJSForApplianceItem(
-        CommonDBTM $item = null,
+        ?CommonDBTM $item = null,
         bool $canedit = true
     ) {
         if ($canedit) {
