@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -73,7 +73,8 @@ class BlacklistedMailContent extends CommonDropdown
             'label' => __('Content'),
             'type'  => 'textarea',
             'rows'  => 20,
-            'list'  => true
+            'list'  => true,
+            'enable_richtext' => false
         ]
         ];
     }
