@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -465,6 +465,9 @@ abstract class CommonITILTask extends CommonDBTM implements CalDAVCompatibleItem
                         '_disablenotif' => true,
                     ];
                     $item->update($input2);
+                } elseif ($item->fields["status"] == CommonITILObject::PLANNED) {
+                    $this->input['_status'] = CommonITILObject::ASSIGNED;
+                    $this->updateParentStatus($this->input['_job'], $this->input);
                 }
 
                 if (!isset($this->input['_disablenotif']) && $CFG_GLPI["use_notifications"]) {
@@ -1110,11 +1113,20 @@ abstract class CommonITILTask extends CommonDBTM implements CalDAVCompatibleItem
         if (!$item = getItemForItemtype($itemtype)) {
             return;
         }
+
+        if (!$item instanceof CommonITILTask) {
+            return;
+        }
+
         $parentitemtype = $item->getItilObjectItemType();
         if (!$parentitem = getItemForItemtype($parentitemtype)) {
             return;
         }
 
+        if (!$parentitem instanceof CommonITILObject) {
+            return;
+        }
+
         $default_options = [
             'genical'             => false,
             'color'               => '',
@@ -1311,7 +1323,7 @@ abstract class CommonITILTask extends CommonDBTM implements CalDAVCompatibleItem
                         $interv[$key]["status"]   = $parentitem->fields["status"];
                         $interv[$key]["priority"] = $parentitem->fields["priority"];
 
-                        $interv[$key]["editable"] = $item->canUpdateITILItem();
+                        $interv[$key]["editable"] = $item->canUpdateItem();
 
                       /// Specific for tickets
                         $interv[$key]["device"] = [];
@@ -1385,6 +1397,9 @@ abstract class CommonITILTask extends CommonDBTM implements CalDAVCompatibleItem
 
         $parenttype = str_replace('Task', '', $itemtype);
         if ($parent = getItemForItemtype($parenttype)) {
+            if (!$parent instanceof CommonITILObject) {
+                return;
+            }
             $parenttype_fk = $parent->getForeignKeyField();
         } else {
             return;
@@ -1945,4 +1960,24 @@ abstract class CommonITILTask extends CommonDBTM implements CalDAVCompatibleItem
             'actiontime' => 0,
         ]);
     }
+
+    /**
+     * Get the number of planned tasks for the parent item of this task
+     *
+     * @return int
+     */
+    public function countPlannedTasks(): int
+    {
+        $parent_item = getItemForItemtype($this->getItilObjectItemType());
+        if (!$parent_item) {
+            return 0;
+        }
+        $parent_fkey = $parent_item->getForeignKeyField();
+        $planned = $this->find([
+            $parent_fkey => $this->fields[$parent_fkey],
+            'state' => \Planning::TODO,
+            'NOT' => ['begin' => null],
+        ]);
+        return count($planned);
+    }
 }
