@@ -302,9 +302,9 @@ abstract class CommonTreeDropdown extends CommonDropdown
 
 
     /**
-     * Clean sons of all parents from caches
+     * Clean from database and caches the sons of the current entity and of all its parents.
      *
-     * @param null|integer $id    Parent id to clean. Default to current id
+     * @param null|integer $id    ID of the entity that have its sons cache to be cleaned.
      * @param boolean      $cache Whether to clean cache (defaults to true)
      *
      * @return void
@@ -322,12 +322,7 @@ abstract class CommonTreeDropdown extends CommonDropdown
         }
 
         $ancestors = getAncestorsOf($this->getTable(), $id);
-        if ($id != $this->getID()) {
-            $ancestors[$id] = "$id";
-        }
-        if (!count($ancestors)) {
-            return;
-        }
+        $ancestors[$id] = "$id";
 
         $DB->update(
             $this->getTable(),
@@ -339,15 +334,10 @@ abstract class CommonTreeDropdown extends CommonDropdown
             ]
         );
 
-       //drop from sons cache when needed
+        // drop from sons cache when needed
         if ($cache) {
             foreach ($ancestors as $ancestor) {
-                $ckey = 'sons_cache_' . $this->getTable() . '_' . $ancestor;
-                $sons = $GLPI_CACHE->get($ckey);
-                if ($sons !== null && isset($sons[$this->getID()])) {
-                    unset($sons[$this->getID()]);
-                    $GLPI_CACHE->set($ckey, $sons);
-                }
+                $GLPI_CACHE->delete('sons_cache_' . $this->getTable() . '_' . $ancestor);
             }
         }
     }
@@ -434,8 +424,7 @@ abstract class CommonTreeDropdown extends CommonDropdown
             }
 
             if ($parent->getFromDB($newParentID)) {
-                $this->cleanParentsSons(null, false);
-                $this->addSonInParents();
+                $this->cleanParentsSons();
                 if ($history) {
                     $newParentNameID = $parent->getNameID(['forceid' => true]);
                     $changes = [
@@ -467,7 +456,10 @@ abstract class CommonTreeDropdown extends CommonDropdown
                     Log::HISTORY_UPDATE_SUBITEM
                 );
             }
+
+            // Force DB cache refresh
             getAncestorsOf(getTableForItemType($this->getType()), $ID);
+            getSonsOf(getTableForItemType($this->getType()), $ID);
         }
     }
 
@@ -1007,7 +999,7 @@ abstract class CommonTreeDropdown extends CommonDropdown
         if (empty($completename)) {
             return $completename;
         }
-        $separator = ' > ';
+        $separator = '>';
         return implode(Sanitizer::sanitize($separator), explode($separator, $completename));
     }
 
@@ -1026,7 +1018,7 @@ abstract class CommonTreeDropdown extends CommonDropdown
         if (empty($completename)) {
             return $completename;
         }
-        $separator = ' > ';
+        $separator = '>';
         return implode($separator, explode(Sanitizer::sanitize($separator), $completename));
     }
 }
