@@ -1484,7 +1484,7 @@ class RacksPluginToCoreCommand extends AbstractCommand
      *
      * @return void
      */
-    private function outputImportError($message, ProgressBar $progress_bar = null)
+    private function outputImportError($message, ?ProgressBar $progress_bar = null)
     {
 
         $skip_errors = $this->input->getOption('skip-errors');
