@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -240,7 +240,7 @@ class CronTask extends CommonDBTM
             ]
         );
 
-        if ($DB->affectedRows($result) > 0) {
+        if ($DB->affectedRows() > 0) {
             $this->timer  = microtime(true);
             $this->volume = 0;
             $log = new CronTaskLog();
@@ -321,7 +321,7 @@ class CronTask extends CommonDBTM
             ]
         );
 
-        if ($DB->affectedRows($result) > 0) {
+        if ($DB->affectedRows() > 0) {
            // No gettext for log but add gettext line to be parsed for pot generation
            // order is important for insertion in english in the database
             if ($log_state === CronTaskLog::STATE_ERROR) {
@@ -1098,16 +1098,16 @@ class CronTask extends CommonDBTM
     public static function register($itemtype, $name, $frequency, $options = [])
     {
 
-       // Check that hook exists
+        // Check that hook exists
         if (!isPluginItemType($itemtype) && !class_exists($itemtype)) {
             return false;
         }
 
-       // manage NS class
+        // manage NS class
         $itemtype = addslashes($itemtype);
 
         $temp = new self();
-       // Avoid duplicate entry
+        // Avoid duplicate entry
         if ($temp->getFromDBbyName($itemtype, $name)) {
             return false;
         }
@@ -1132,7 +1132,7 @@ class CronTask extends CommonDBTM
             && ($input['allowmode'] & self::MODE_EXTERNAL)
             && !isset($input['mode'])
         ) {
-           // Downstream packages may provide a good system cron
+            // Downstream packages may provide a good system cron
             $input['mode'] = self::MODE_EXTERNAL;
         }
         return $temp->add($input);
@@ -1579,7 +1579,7 @@ class CronTask extends CommonDBTM
         CommonDBTM $item,
         array $ids
     ) {
-
+        /** @var CronTask $item */
         switch ($ma->getAction()) {
             case 'reset':
                 foreach ($ids as $key) {
@@ -1995,7 +1995,7 @@ class CronTask extends CommonDBTM
             $vol += Event::cleanOld($task->fields['param']);
         }
 
-        foreach ($DB->request('glpi_crontasks') as $data) {
+        foreach ($DB->request(self::getTable()) as $data) {
             if ($data['logs_lifetime'] > 0) {
                 $vol += CronTaskLog::cleanOld($data['id'], $data['logs_lifetime']);
             }
