@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -118,7 +118,7 @@ trait AssetImage
                 $prefix = $input["_prefix_pictures"][$input_key] ?? '';
 
                 if ($dest = Toolbox::savePicture($src, $prefix)) {
-                    $new_pictures[$input_key] = $dest;
+                    $new_pictures[] = $dest;
                 } else {
                     Session::addMessageAfterRedirect(__('Unable to save picture file.'), true, ERROR);
                 }
