@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -43,6 +43,7 @@ use Dropdown;
 use Entity;
 use ExtraVisibilityCriteria;
 use Glpi\RichText\RichText;
+use Glpi\Toolbox\ArrayNormalizer;
 use Glpi\Toolbox\Sanitizer;
 use Group_User;
 use Html;
@@ -116,6 +117,8 @@ trait PlanningEvent
         /** @var \DBmysql $DB */
         global $DB;
 
+        $input = $this->prepareGuestsInput($input);
+
         if (
             $DB->fieldExists(static::getTable(), 'users_id')
             && (!isset($input['users_id'])
@@ -124,11 +127,6 @@ trait PlanningEvent
             $input['users_id'] = Session::getLoginUserID();
         }
 
-       // manage guests
-        if (isset($input['users_id_guests']) && is_array($input['users_id_guests'])) {
-            $input['users_id_guests'] = exportArrayToDB($input['users_id_guests']);
-        }
-
         Toolbox::manageBeginAndEndPlanDates($input['plan']);
 
         if (!isset($input['uuid'])) {
@@ -179,12 +177,11 @@ trait PlanningEvent
 
     public function prepareInputForUpdate($input)
     {
-       // manage guests
-        if (isset($input['users_id_guests']) && is_array($input['users_id_guests'])) {
-            $input['users_id_guests'] = exportArrayToDB($input['users_id_guests']);
+        $input = $this->prepareGuestsInput($input);
 
-           // avoid warning on update method (string comparison with old value)
-            $this->fields['users_id_guests'] = exportArrayToDB($input['users_id_guests']);
+        if (isset($this->fields['users_id_guests']) && is_array($this->fields['users_id_guests'])) {
+            // avoid warning on update method (string comparison with old value)
+            $this->fields['users_id_guests'] = exportArrayToDB($this->fields['users_id_guests']);
         }
 
         Toolbox::manageBeginAndEndPlanDates($input['plan']);
@@ -234,6 +231,17 @@ trait PlanningEvent
         return $input;
     }
 
+    private function prepareGuestsInput(array $input): array
+    {
+        if (isset($input['users_id_guests']) && is_array($input['users_id_guests'])) {
+            $input['users_id_guests'] = exportArrayToDB(
+                ArrayNormalizer::normalizeValues($input['users_id_guests'], 'intval')
+            );
+        }
+
+        return $input;
+    }
+
     public function encodeRrule(array $rrule = [])
     {
 
