@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -67,6 +67,8 @@ trait TreeBrowse
         $browse      = (int)($_REQUEST['browse'] ?? 0);
         $is_deleted  = (int)($_REQUEST['is_deleted'] ?? 0);
         $criteria    = json_encode($params['criteria']);
+        $sort        = json_encode($_REQUEST['sort'] ?? []);
+        $order       = json_encode($_REQUEST['order'] ?? []);
 
         $category_list = json_encode(self::getTreeCategoryList($itemtype, $params));
         $no_cat_found  = __s("No category found");
@@ -83,16 +85,22 @@ trait TreeBrowse
                 'start': $start,
                 'browse': $browse,
                 'is_deleted': $is_deleted,
-                'criteria': $criteria
+                'criteria': $criteria,
+                'sort': $sort,
+                'order': $order,
             });
         };
 JAVASCRIPT;
 
         if ($update) {
-            $category_list = json_encode(self::getTreeCategoryList($itemtype, $params));
             $JS .= <<<JAVASCRIPT
             $('#tree_category').fancytree('option', 'source', {$category_list});
 JAVASCRIPT;
+
+            $params['criteria'][] = $_SESSION['treebrowse'][$itemtype];
+            $results = Search::getDatas($itemtype, $params);
+            $results['searchform_id'] = $params['searchform_id'] ?? null;
+            Search::displayData($results);
         } else {
             $JS .= <<<JAVASCRIPT
             $(function() {
@@ -250,14 +258,12 @@ JAVASCRIPT;
                 ]
             ]
         )->current();
-        if ($no_cat_count['cpt'] > 0) {
-            $categories[] = [
-                'id'          => -1,
-                'name'        => __s('Without Category'),
-                'items_count' => $no_cat_count['cpt'],
-                $cat_fk       => 0,
-            ];
-        }
+        $categories[] = [
+            'id'          => -1,
+            'name'        => __s('Without Category'),
+            'items_count' => $no_cat_count['cpt'],
+            $cat_fk       => 0,
+        ];
 
         // construct flat data
         $nodes   = [];
@@ -281,7 +287,7 @@ JAVASCRIPT;
             $nodes[] = $node;
         }
 
-       // recursive construct tree data
+        // recursive construct tree data
         $buildtree = function (array &$elements, $parent = 0) use (&$buildtree) {
             $branch = [];
 
@@ -289,7 +295,7 @@ JAVASCRIPT;
                 if ($element['parent'] === $parent) {
                     $children = $buildtree($elements, $element['key']);
                     if (count($children) > 0) {
-                         $element['children'] = $children;
+                        $element['children'] = $children;
                     }
                     $branch[] = $element;
                     unset($elements[$index]);
