@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -97,8 +97,8 @@ class HTMLTableRow extends HTMLTableEntity
     public function addCell(
         HTMLTableHeader $header,
         $content,
-        HTMLTableCell $father = null,
-        CommonDBTM $item = null
+        ?HTMLTableCell $father = null,
+        ?CommonDBTM $item = null
     ) {
 
         if (!$this->group->haveHeader($header)) {
