@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -40,7 +40,7 @@ class HTMLTableSubHeader extends HTMLTableHeader
 {
    // The headers of each column
     private $header;
-
+    public $numberOfSubHeaders;
 
     /**
      * @param HTMLTableSuperHeader $header
@@ -52,7 +52,7 @@ class HTMLTableSubHeader extends HTMLTableHeader
         HTMLTableSuperHeader $header,
         $name,
         $content,
-        HTMLTableHeader $father = null
+        ?HTMLTableHeader $father = null
     ) {
 
         $this->header = $header;
