@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -159,7 +159,7 @@ abstract class ITILTemplate extends CommonDropdown
      * @param boolean $withtypeandcategory (default 0)
      * @param boolean $withitemtype        (default 0)
      **/
-    public static function getAllowedFields($withtypeandcategory = 0, $withitemtype = 0)
+    public static function getAllowedFields($withtypeandcategory = false, $withitemtype = false)
     {
 
         static $allowed_fields = [];
@@ -370,7 +370,7 @@ abstract class ITILTemplate extends CommonDropdown
                 'glpi_itilcategories'
             ),
             $ticket->getSearchOptionIDByField('field', 'type', 'glpi_tickets'),
-            $ticket->getSearchOptionIDByField('field', 'items_id', 'glpi_tickets'),
+            $ticket->getSearchOptionIDByField('field', 'items_id', 'glpi_items_tickets'),
             $ticket->getSearchOptionIDByField('field', 'name', 'glpi_documents'),
             66 // users_id_observer
         ];
@@ -567,7 +567,10 @@ abstract class ITILTemplate extends CommonDropdown
         switch ($ma->getAction()) {
             case 'merge':
                 foreach ($ids as $key) {
-                    if ($item->can($key, UPDATE)) {
+                    if (
+                        ($item instanceof ITILTemplate)
+                        && $item->can($key, UPDATE)
+                    ) {
                         if ($item->getEntityID() == $_SESSION['glpiactive_entity']) {
                             if (
                                 $item->update(['id'           => $key,
