@@ -116,7 +116,7 @@ class Antivirus extends InventoryAsset
         $value = $this->data;
         $computerAntivirus = new ComputerAntivirus();
 
-       //check for existing
+        //check for existing
         foreach ($value as $k => $val) {
             $compare = ['name' => $val->name, 'antivirus_version' => $val->antivirus_version];
             $compare = array_map('strtolower', $compare);
@@ -135,7 +135,7 @@ class Antivirus extends InventoryAsset
             }
         }
 
-        if ((!$this->main_asset || !$this->main_asset->isPartial()) && count($db_antivirus) !== 0) {
+        if (count($db_antivirus) !== 0) {
             foreach ($db_antivirus as $idtmp => $data) {
                 if ($data['is_dynamic'] == 1) {
                     $computerAntivirus->delete(['id' => $idtmp], true);
