@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @copyright 2010-2022 by the FusionInventory Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
@@ -360,7 +360,7 @@ class NetworkPort extends InventoryAsset
         }
         if (count($found_macs) > 1) { // MultipleMac
            //do not manage MAC addresses if we found one NetworkEquipment
-            if (isset($this->connections['NetworkEquipment'])) {
+            if (isset($this->connection_ports['NetworkEquipment'])) {
                 return;
             }
 
