@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -52,21 +52,20 @@ class Item_Rack extends CommonDBRelation
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
     {
         $nb = 0;
-        switch ($item->getType()) {
-            default:
-                if ($_SESSION['glpishow_count_on_tabs']) {
-                    $nb = countElementsInTable(
-                        self::getTable(),
-                        ['racks_id'  => $item->getID()]
-                    );
-                    $nb += countElementsInTable(
-                        PDU_Rack::getTable(),
-                        ['racks_id'  => $item->getID()]
-                    );
-                }
-                return self::createTabEntry(self::getTypeName(Session::getPluralNumber()), $nb);
+        if (
+            $_SESSION['glpishow_count_on_tabs']
+            && ($item instanceof CommonDBTM)
+        ) {
+            $nb = countElementsInTable(
+                self::getTable(),
+                ['racks_id'  => $item->getID()]
+            );
+            $nb += countElementsInTable(
+                PDU_Rack::getTable(),
+                ['racks_id'  => $item->getID()]
+            );
         }
-        return '';
+        return self::createTabEntry(self::getTypeName(Session::getPluralNumber()), $nb);
     }
 
     public static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0)
@@ -573,6 +572,7 @@ JAVASCRIPT;
         } else {
             $types = array_combine($CFG_GLPI['rackable_types'], $CFG_GLPI['rackable_types']);
             foreach ($types as $type => &$text) {
+                /** @var class-string $type */
                 $text = $type::getTypeName(1);
             }
             Dropdown::showFromArray(
@@ -589,28 +589,23 @@ JAVASCRIPT;
        //get all used items
         $used = $used_reserved = [];
         $iterator = $DB->request([
-            'FROM' => $this->getTable()
+            'SELECT' => ['itemtype', 'items_id', 'is_reserved'],
+            'FROM' => static::getTable()
         ]);
         foreach ($iterator as $row) {
+            if ($row['is_reserved']) {
+                $used_reserved[$row['itemtype']][] = $row['items_id'];
+            }
             $used[$row['itemtype']][] = $row['items_id'];
         }
-       // find used pdu (not racked)
-        foreach (PDU_Rack::getUsed() as $used_pdu) {
+        // find used pdu (not racked)
+        foreach (PDU_Rack::getUsed(['pdus_id']) as $used_pdu) {
             $used['PDU'][] = $used_pdu['pdus_id'];
         }
-       // get all reserved items
-        $iterator = $DB->request([
-            'FROM'  => $this->getTable(),
-            'WHERE' => [
-                'is_reserved' => true
-            ]
-        ]);
-        foreach ($iterator as $row) {
-            $used_reserved[$row['itemtype']][] = $row['items_id'];
-        }
 
        //items part of an enclosure should not be listed
         $iterator = $DB->request([
+            'SELECT' => ['itemtype', 'items_id'],
             'FROM'   => Item_Enclosure::getTable()
         ]);
         foreach ($iterator as $row) {
@@ -1043,6 +1038,10 @@ JAVASCRIPT;
                 }
             }
 
+            /**
+             * @var int $position
+             * @var int $required_units
+             */
             if (
                 $position > $rack->fields['number_units'] ||
                 $position + $required_units  > $rack->fields['number_units'] + 1
