@@ -249,7 +249,7 @@ abstract class LevelAgreement extends CommonDBChild
     /**
      * Get possibles keys and labels for the definition_time field
      *
-     * @return string
+     * @return array
      *
      * @since 10.0.0
      */
@@ -570,6 +570,7 @@ abstract class LevelAgreement extends CommonDBChild
             $nb = 0;
             switch ($item->getType()) {
                 case 'SLM':
+                    /** @var \SLM $item */
                     if ($_SESSION['glpishow_count_on_tabs']) {
                         $nb = countElementsInTable(
                             self::getTable(),
@@ -1151,6 +1152,18 @@ abstract class LevelAgreement extends CommonDBChild
         Rule::cleanForItemAction($this);
     }
 
+    public function post_clone($source, $history)
+    {
+        // Clone levels
+        $classname = get_called_class();
+        $fk        = getForeignKeyFieldForItemType($classname);
+        $level     = new static::$levelclass();
+        foreach ($level->find([$fk => $source->getID()]) as $data) {
+            $level->getFromDB($data['id']);
+            $level->clone([$fk => $this->getID()]);
+        }
+    }
+
     /**
      * Getter for the protected $levelclass static property
      *
