@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -506,7 +506,7 @@ class Notification extends CommonDBTM
         switch ($ma->getAction()) {
             case 'add_template':
                 $notification_notificationtemplate = new Notification_NotificationTemplate();
-                $notification_notificationtemplate->showFormMassiveAction($ma);
+                $notification_notificationtemplate->showFormMassiveAction();
                 return true;
             case 'remove_all_template':
                 echo Html::submit(__('Delete'), ['name' => 'massiveaction']);
