@@ -531,7 +531,7 @@ class ObjectLock extends CommonDBTM
             ) {
                 if (
                     !$ol->autoLockMode()
-                    || !$ol->lockObject($options['id'])
+                    || !$ol->lockObject()
                 ) {
                     $options['locked'] = 1;
                 }
@@ -682,7 +682,7 @@ class ObjectLock extends CommonDBTM
      *    >0 : done
      *    <0 : to be run again (not finished)
      *     0 : nothing to do
-     **/
+     */
     public static function cronUnlockObject($task)
     {
        // here we have to delete old locks
