@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -75,7 +75,7 @@ class Peripheral extends CommonDBTM
      **/
     public static function getTypeName($nb = 0)
     {
-        return _n('Device', 'Devices', $nb);
+        return _n('Peripheral', 'Peripherals', $nb);
     }
 
 
@@ -372,6 +372,8 @@ class Peripheral extends CommonDBTM
         $tab = array_merge($tab, Rack::rawSearchOptionsToAdd(get_class($this)));
 
         $tab = array_merge($tab, Socket::rawSearchOptionsToAdd());
+
+        $tab = array_merge($tab, DCRoom::rawSearchOptionsToAdd());
         return $tab;
     }
 
