@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -192,7 +192,7 @@ class Problem extends CommonITILObject
     public static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0)
     {
 
-        switch ($item->getType()) {
+        switch (get_class($item)) {
             case __CLASS__:
                 switch ($tabnum) {
                     case 1:
@@ -548,6 +548,10 @@ class Problem extends CommonITILObject
             ]
         ];
 
+        if (Session::haveRight('change', READ)) {
+            $tab = array_merge($tab, Change::rawSearchOptionsToAdd('Problem'));
+        }
+
         return $tab;
     }
 
@@ -990,7 +994,7 @@ class Problem extends CommonITILObject
                         'values' => []
                     ];
 
-                    if ($problem->getFromDBwithData($data['id'], 0)) {
+                    if ($problem->getFromDBwithData($data['id'])) {
                         $bgcolor = $_SESSION["glpipriority_" . $problem->fields["priority"]];
                         $name = sprintf(__('%1$s: %2$s'), __('ID'), $problem->fields["id"]);
                         $row['values'][] = [
@@ -1326,8 +1330,8 @@ class Problem extends CommonITILObject
             'reset'    => 'reset',
         ];
 
-        switch ($item->getType()) {
-            case 'User':
+        switch (get_class($item)) {
+            case User::class:
                 $restrict['glpi_problems_users.users_id'] = $item->getID();
 
                 $options['criteria'][0]['field']      = 4; // status
@@ -1347,7 +1351,7 @@ class Problem extends CommonITILObject
 
                 break;
 
-            case 'Supplier':
+            case Supplier::class:
                 $restrict['glpi_problems_suppliers.suppliers_id'] = $item->getID();
 
                 $options['criteria'][0]['field']      = 6;
@@ -1356,7 +1360,7 @@ class Problem extends CommonITILObject
                 $options['criteria'][0]['link']       = 'AND';
                 break;
 
-            case 'Group':
+            case Group::class:
                // Mini search engine
                 if ($item->haveChildren()) {
                     $tree = Session::getSavedOption(__CLASS__, 'tree', 0);
@@ -1551,11 +1555,19 @@ class Problem extends CommonITILObject
             'entities_id'                => $_SESSION['glpiactive_entity'],
             'itilcategories_id'          => 0,
             'actiontime'                 => 0,
+            'date'                       => 'NULL',
             '_add_validation'            => 0,
             'users_id_validate'          => [],
             '_tasktemplates_id'          => [],
             'items_id'                   => 0,
-            '_actors'                     => [],
+            '_actors'                    => [],
+            'status'                     => self::INCOMING,
+            'time_to_resolve'            => 'NULL',
+            'itemtype'                   => '',
+            'locations_id'               => 0,
+            'impactcontent'              => '',
+            'causecontent'               => '',
+            'symptomcontent'             => '',
         ];
     }
 
