@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -88,8 +88,8 @@ class ProjectTaskTeam extends CommonDBRelation
 
         if (!$withtemplate && static::canView()) {
             $nb = 0;
-            switch ($item->getType()) {
-                case 'ProjectTask':
+            switch (get_class($item)) {
+                case ProjectTask::class:
                     if ($_SESSION['glpishow_count_on_tabs']) {
                         $nb = $item->getTeamCount();
                     }
@@ -103,8 +103,8 @@ class ProjectTaskTeam extends CommonDBRelation
     public static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0)
     {
 
-        switch ($item->getType()) {
-            case 'ProjectTask':
+        switch (get_class($item)) {
+            case ProjectTask::class:
                 $item->showTeam($item);
                 break;
         }
