@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -91,8 +91,8 @@ class ProjectTeam extends CommonDBRelation
 
         if (self::canView()) {
             $nb = 0;
-            switch ($item->getType()) {
-                case 'Project':
+            switch (get_class($item)) {
+                case Project::class:
                     if ($_SESSION['glpishow_count_on_tabs']) {
                         $nb = $item->getTeamCount();
                     }
@@ -106,8 +106,8 @@ class ProjectTeam extends CommonDBRelation
     public static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0)
     {
 
-        switch ($item->getType()) {
-            case 'Project':
+        switch (get_class($item)) {
+            case Project::class:
                 $item->showTeam($item);
         }
         return true;
