@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -216,7 +216,7 @@ class RuleDictionnarySoftwareCollection extends RuleCollection
                 $i++;
                 if ($maxtime) {
                     $crt = explode(" ", microtime());
-                    if (($crt[0] + $crt[1]) > $maxtime) {
+                    if (((float)$crt[0] + (float)$crt[1]) > $maxtime) {
                         break;
                     }
                 }
