@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @copyright 2010-2022 by the FusionInventory Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
@@ -73,13 +73,6 @@ class RuleImportAsset extends Rule
         return $col->getTitle();
     }
 
-
-    public function maxActionsCount()
-    {
-        return 1;
-    }
-
-
     public function getCriterias()
     {
 
@@ -1009,6 +1002,14 @@ class RuleImportAsset extends Rule
                         if (is_a($class, \Glpi\Inventory\Asset\MainAsset::class)) {
                             $back_class = $class->getItemtype();
                         }
+
+                        if ($back_class === Unmanaged::class) {
+                            $conf = new \Glpi\Inventory\Conf();
+                            if ($conf->import_unmanaged == 0) {
+                                return $output;
+                            }
+                        }
+
                         if ($class && !isset($params['return'])) {
                             $class->rulepassed("0", $back_class, $rules_id);
                         }
