@@ -7,9 +7,8 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
- * @copyright 2010-2022 by the FusionInventory Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
  * ---------------------------------------------------------------------
@@ -54,17 +53,6 @@ class RuleImportComputer extends Rule
         return __('Rules for import and link computers');
     }
 
-
-    /**
-     * @see Rule::maxActionsCount()
-     **/
-    public function maxActionsCount()
-    {
-       // Unlimited
-        return 1;
-    }
-
-
     public function getCriterias()
     {
 
@@ -145,7 +133,7 @@ class RuleImportComputer extends Rule
      *
      * @see Rule::displayAdditionRuleActionValue()
      *
-     * @param string value the value for this action
+     * @param string $value the value for this action
      *
      * @return string the label's value or ''
      **/
