@@ -101,7 +101,9 @@ class Session
                 }
             }
             self::destroy();
-            session_regenerate_id();
+            if (!defined('TU_USER')) { //FIXME: no idea why this fails with phpunit... :(
+                session_regenerate_id();
+            }
             self::start();
             $_SESSION = $save;
             $_SESSION['valid_id'] = session_id();
@@ -376,6 +378,46 @@ class Session
     }
 
 
+    /**
+     * Check if active entities should be reloaded.
+     *
+     * @return bool true if active entities should be reloaded, false otherwise
+     */
+    public static function shouldReloadActiveEntities(): bool
+    {
+        if (!array_key_exists('glpiactive_entity', $_SESSION)) {
+            return false;
+        }
+        $glpiactiveentities = $_SESSION['glpiactiveentities'] ?? [];
+        if (count($glpiactiveentities)) {
+            $glpiactive_entity = $_SESSION['glpiactive_entity'];
+            $glpiactive_entity_recursive = $_SESSION['glpiactive_entity_recursive'] ?? false;
+            $entities = [$glpiactive_entity => $glpiactive_entity];
+            if (
+                ($_SESSION["glpientity_fullstructure"] ?? false)
+                && isset($_SESSION['glpiactiveprofile']['entities'])
+            ) {
+                foreach ($_SESSION['glpiactiveprofile']['entities'] as $val) {
+                    $entities[$val['id']] = $val['id'];
+                    if ($val['is_recursive']) {
+                        $sons = getSonsOf("glpi_entities", $val['id']);
+                        foreach ($sons as $key2 => $val2) {
+                            $entities[$key2] = $key2;
+                        }
+                    }
+                }
+            } elseif ($glpiactive_entity_recursive) {
+                $entities = getSonsOf("glpi_entities", $glpiactive_entity);
+            }
+
+            return count($entities) !== count($glpiactiveentities)
+                || array_diff($entities, $glpiactiveentities) !== []
+                || array_diff($glpiactiveentities, $entities) !== [];
+        }
+        return false;
+    }
+
+
     /**
      * Change active entity to the $ID one. Update glpiactiveentities session variable.
      * Reload groups related to this entity.
@@ -392,6 +434,8 @@ class Session
         $newentities = [];
         $ancestors = [];
 
+        $_SESSION["glpientity_fullstructure"] = ($ID === 'all');
+
         if (isset($_SESSION['glpiactiveprofile'])) {
             if ($ID === "all") {
                 foreach ($_SESSION['glpiactiveprofile']['entities'] as $val) {
@@ -413,6 +457,7 @@ class Session
                         }
                     }
                 }
+                $is_recursive = true;
             } else {
                 $ID = (int)$ID;
 
@@ -460,19 +505,7 @@ class Session
                 $active
             );
             $_SESSION["glpiactive_entity_shortname"] = getTreeLeafValueName("glpi_entities", $active);
-            if ($is_recursive) {
-                //TRANS: %s is the entity name
-                $_SESSION["glpiactive_entity_name"]      = sprintf(
-                    __('%1$s (%2$s)'),
-                    $_SESSION["glpiactive_entity_name"],
-                    __('tree structure')
-                );
-                 $_SESSION["glpiactive_entity_shortname"] = sprintf(
-                     __('%1$s (%2$s)'),
-                     $_SESSION["glpiactive_entity_shortname"],
-                     __('tree structure')
-                 );
-            } elseif ($ID == "all") {
+            if ($ID == "all") {
                 //TRANS: %s is the entity name
                 $_SESSION["glpiactive_entity_name"]      = sprintf(
                     __('%1$s (%2$s)'),
@@ -484,6 +517,18 @@ class Session
                     $_SESSION["glpiactive_entity_shortname"],
                     __('full structure')
                 );
+            } elseif ($is_recursive) {
+                //TRANS: %s is the entity name
+                $_SESSION["glpiactive_entity_name"]      = sprintf(
+                    __('%1$s (%2$s)'),
+                    $_SESSION["glpiactive_entity_name"],
+                    __('tree structure')
+                );
+                 $_SESSION["glpiactive_entity_shortname"] = sprintf(
+                     __('%1$s (%2$s)'),
+                     $_SESSION["glpiactive_entity_shortname"],
+                     __('tree structure')
+                 );
             }
 
             if (countElementsInTable('glpi_entities') <= count($_SESSION['glpiactiveentities'])) {
@@ -533,17 +578,20 @@ class Session
                 Search::resetSaveSearch();
                 $active_entity_done = false;
 
-               // Try to load default entity if it is a root entity
+                // Try to load default entity if it is a root entity
                 foreach ($data['entities'] as $val) {
-                    if ($val['id'] == $_SESSION["glpidefault_entity"]) {
+                    if ($val['id'] === $_SESSION["glpidefault_entity"]) {
                         if (self::changeActiveEntities($val['id'], $val['is_recursive'])) {
-                             $active_entity_done = true;
+                            $active_entity_done = true;
                         }
                     }
                 }
                 if (!$active_entity_done) {
                    // Try to load default entity
-                    if (!self::changeActiveEntities($_SESSION["glpidefault_entity"], true)) {
+                    if (
+                        $_SESSION["glpidefault_entity"] === null
+                        || !self::changeActiveEntities($_SESSION["glpidefault_entity"], true)
+                    ) {
                         // Load all entities
                         self::changeActiveEntities("all");
                     }
@@ -1299,7 +1347,7 @@ class Session
      * @param string  $module Module to check
      * @param integer $right  Right to check
      *
-     * @return boolean
+     * @return boolean|int
      **/
     public static function haveRight($module, $right)
     {
@@ -1801,6 +1849,10 @@ class Session
      */
     public static function canImpersonate($user_id, ?string &$message = null)
     {
+        // Cannot impersonate if we don't have config right
+        if (!self::haveRight(Config::$rightname, UPDATE)) {
+            return false;
+        }
 
         if (
             $user_id <= 0 || self::getLoginUserID() == $user_id
@@ -1810,11 +1862,6 @@ class Session
             return false; // Cannot impersonate invalid user, self, or already impersonated user
         }
 
-        // Cannot impersonate if we don't have config right
-        if (!self::haveRight(Config::$rightname, UPDATE)) {
-            return false;
-        }
-
         // Cannot impersonate inactive user
         $user = new User();
         if (!$user->getFromDB($user_id) || !$user->getField('is_active')) {
