@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -51,6 +51,12 @@ class SingletonRuleList
      **/
     public static function &getInstance($type, $entity)
     {
+        //FIXME: can be removed when using phpunit 10 and process-isolation
+        if (defined('TU_USER')) {
+            $o = new self();
+            return $o;
+        }
+
         static $instances = [];
 
         if (!isset($instances[$type][$entity])) {
