@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -576,11 +576,13 @@ class State extends CommonTreeDropdown
             'WHERE'  => $where
         ];
         $row = $DB->request($query)->current();
-        return (int)$row['cpt'] == 0;
+        return ((int)$row['cpt'] === 0);
     }
 
     /**
      * Get visibility fields from conf
+     *
+     * @return array<string,string>
      */
     protected function getvisibilityFields(): array
     {
