@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -54,6 +54,40 @@ class UserEmail extends CommonDBChild
         return _n('Email', 'Emails', $nb);
     }
 
+    public function canChildItem($methodItem, $methodNotItem)
+    {
+        $users_id = $this->input['users_id'] ?? $this->fields['users_id'] ?? null;
+        if ($users_id !== null && !$this->canAlterUserEmails((int) $users_id)) {
+            return false;
+        }
+
+        return parent::canChildItem($methodItem, $methodNotItem);
+    }
+
+    /**
+     * Indicates whether the current user can alter the email addresses from the target user.
+     *
+     * @param int $target_user_id
+     * @return bool
+     */
+    private function canAlterUserEmails(int $target_user_id): bool
+    {
+        $session_user_id = Session::getLoginUserID();
+
+        if ($session_user_id === false) {
+            // No active user session, action is made by a cron or a system routine, no need to check.
+            return true;
+        }
+
+        if ($target_user_id === $session_user_id) {
+            // Email is attached to the current user, no need to check.
+            return true;
+        }
+
+        // Current user can alter target user's emails only if he has more rights.
+        $user = new User();
+        return $user->currentUserHaveMoreRightThan($target_user_id);
+    }
 
     /**
      * Get default email for user. If no default email get first one
@@ -221,7 +255,7 @@ class UserEmail extends CommonDBChild
             !$user->can($users_id, READ)
             && ($users_id != Session::getLoginUserID())
         ) {
-            return false;
+            return;
         }
         $canedit = ($user->can($users_id, UPDATE) || ($users_id == Session::getLoginUserID()));
 
